@@ -148,6 +148,7 @@ class BaseEndpoint(object):
     search_fields = None
     ordering_fields = None
     page_size = None
+    url = None
     viewset = None
 
     read_only = False
@@ -168,7 +169,7 @@ class BaseEndpoint(object):
     _default_language_field_names = None
     _fieldsets_location = ''
 
-    def get_languages(self):
+    def get_languages(self, request=None):
         return get_languages()
 
     @property
@@ -227,10 +228,13 @@ class BaseEndpoint(object):
                 self.serializer = self.viewset.get_serializer_class()
 
         if data is None:
-           return self.serializer
+            return self.serializer
 
         return self.serializer(data)
 
+    def get_serializer_instance(self, request=None):
+        return self.get_serializer()()
+
     def get_base_viewset(self):
         if not self.read_only:
             return self.base_viewset
@@ -258,20 +262,27 @@ class BaseEndpoint(object):
             self.model_name.replace('_', '-')
         )
 
-    def _get_field_dict(self, field):
+    def _get_field_dict(self, field, serializer_instance=None):
         foreign_key_as_list = (isinstance(self.foreign_key_as_list, Iterable) and field in self.foreign_key_as_list) \
             or (not isinstance(self.foreign_key_as_list, Iterable) and self.foreign_key_as_list)
 
-        return get_field_dict(field, self.get_serializer(), self.get_translated_fields(),
+        if serializer_instance is None:
+            serializer_instance = self.get_serializer()()
+
+        return get_field_dict(field, serializer_instance, self.get_translated_fields(),
                               self.fields_annotation, self.model, foreign_key_as_list=foreign_key_as_list)
 
-    def get_fields(self):
+    def get_field_names(self, request=None):
+        return self.get_serializer_instance(request).fields.keys()
+
+    def get_fields(self, request=None):
+        serializer_instance = self.get_serializer_instance(request)
         return [
-            self._get_field_dict(field)
-            for field in self.get_fields_for_serializer()
+            self._get_field_dict(field, serializer_instance)
+            for field in self.get_field_names(request)
         ]
 
-    def get_fieldsets(self):
+    def get_fieldsets(self, request=None):
 
         if django_settings.DEBUG:
             fieldsets_path = os.path.join(
@@ -298,19 +309,21 @@ class BaseEndpoint(object):
                     else field
                     for field in self.fieldsets]
 
+        serializer_instance = self.get_serializer_instance(request)
+
         return [{'key': field}
-                for field in self.get_fields_for_serializer()
+                for field in self.get_field_names(request)
                 if field != 'id' and field != '__str__' and
                 field not in self.translated_field_names and
-                self._get_field_dict(field).get('type', '')[:6] != 'tomany']
+                self._get_field_dict(field, serializer_instance).get('type', '')[:6] != 'tomany']
 
-    def get_list_display(self):
+    def get_list_display(self, request=None):
         if self.list_display is None:
-            if '__str__' in self.get_fields_for_serializer():
+            if '__str__' in self.get_field_names(request):
                 return ['__str__', ]
             return [self.get_fields()[0]['key']]
         elif self.list_display == '__all__':
-            return self.get_fields_for_serializer()
+            return self.get_field_names(request)
         return self.list_display
 
     def _get_endpoint_list(self, name, check_viewset_if_none=False):
@@ -339,11 +352,11 @@ class BaseEndpoint(object):
         fields = self._get_endpoint_list('ordering_fields', check_viewset_if_none)
         return fields
 
-    def get_needs(self):
+    def get_needs(self, request=None):
         model_fields = [
             f
             for f in self.model._meta.get_fields()
-            if f.is_relation and f.name in self.get_fields_for_serializer() and (
+            if f.is_relation and f.name in self.get_field_names(request) and (
                 not isinstance(f, ForeignKey) or
                 self.foreign_key_as_list is False or (
                    isinstance(self.foreign_key_as_list, Iterable) and
@@ -365,15 +378,15 @@ class BaseEndpoint(object):
             } for model in related_models if model is not None
         ]
 
-    def get_list_editable(self):
+    def get_list_editable(self, request=None):
         if self.list_editable is None:
             return []
         return self.list_editable
 
-    def get_sortable_by(self):
+    def get_sortable_by(self, request=None):
         return self.sortable_by
 
-    def get_translated_fields(self):
+    def get_translated_fields(self, request=None):
         if self._translated_fields is None:
             models = translator.get_registered_models()
             if self.model in models:
@@ -385,10 +398,10 @@ class BaseEndpoint(object):
         return self._translated_fields
 
     @property
-    def translated_field_names(self):
+    def translated_field_names(self, request=None):
         if self._translated_field_names is None:
             rv = []
-            for field in self.get_translated_fields():
+            for field in self.get_translated_fields(request):
                 for language in self.get_languages():
                     lang = language.replace('-', '_')
                     rv.append('{}_{}'.format(field, lang))
@@ -396,12 +409,12 @@ class BaseEndpoint(object):
         return self._translated_field_names
 
     @property
-    def default_language_field_names(self):
+    def default_language_field_names(self, request=None):
         from django.conf import settings as django_settings
         if self._default_language_field_names is None:
             lang = django_settings.LANGUAGE_CODE.replace('-', '_')
             rv = []
-            for field in self.get_translated_fields():
+            for field in self.get_translated_fields(request):
                 rv.append('{}_{}'.format(field, lang))
             self._default_language_field_names = rv
         return self._default_language_field_names
@@ -414,7 +427,7 @@ class BaseEndpoint(object):
             verb = list(action.mapping.keys())[0]
         return verb
 
-    def get_custom_actions(self):
+    def get_custom_actions(self, request=None):
         rv = []
         viewset = self.get_viewset()
 
@@ -437,7 +450,7 @@ class BaseEndpoint(object):
 
         return rv
 
-    def get_bulk_actions(self):
+    def get_bulk_actions(self, request=None):
         rv = []
         viewset = self.get_viewset()
 
@@ -459,7 +472,7 @@ class BaseEndpoint(object):
 
         return rv
 
-    def get_list_actions(self):
+    def get_list_actions(self, request=None):
         rv = []
         viewset = self.get_viewset()
 
